@@ -348,6 +348,15 @@ class WinOSClient:
 
         return os.path.exists(path)
 
+    def get_content(self, path):
+        return self.run_ps(f'Get-Content "{path}"')
+
+    def get_json(self, path: str) -> dict:
+        """Read JSON file as string and pretty print it into console"""
+
+        file = self.get_content(path)
+        return file.json()
+
     @staticmethod
     def get_local_hostname_ip():
         """Get local IP and hostname
